@@ -123,6 +123,8 @@ def get_service_name(resource):
         return "cognito-idp"
     if parts[-2] == "Elasticsearch":
         return "es"
+    if parts[-2] == "OpenSearchService":
+        return "opensearch"
     if parts[-2] == "KinesisFirehose":
         return "firehose"
     if parts[-2] == "ResourceGroups":
@@ -1613,6 +1615,13 @@ class TemplateDeployer:
                         if not self.all_resource_dependencies_satisfied(resource):
                             j += 1
                             continue
+                    elif action == "Remove":
+                        should_remove = self.prepare_should_deploy_change(
+                            resource_id, change, stack, new_resources
+                        )
+                        if not should_remove:
+                            del changes[j]
+                            continue
                     self.apply_change(change, stack=stack)
                     changes_done.append(change)
                     del changes[j]
@@ -1666,6 +1675,13 @@ class TemplateDeployer:
                     resource.get("Type"),
                 )
                 return False
+        elif action == "Remove":
+            should_remove = self.is_deployable_resource(resource)
+            if not should_remove:
+                LOG.debug(
+                    f"Action 'remove' not yet implemented for CF resource type {resource.get('Type')}"
+                )
+            return should_remove
         return True
 
     def apply_change(self, change, stack):
